package com.xlht.xlhtproject.service.impl;

import java.util.List;

import com.xlht.xlhtproject.domain.TXlhtConf;
import com.xlht.xlhtproject.mapper.TXlhtConfMapper;
import com.xlht.xlhtproject.service.ITXlhtConfService;
import com.xlht.xlhtproject.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 指标配置Service业务层处理
 * 
 * @author slibra
 * @date 2024-10-13
 */
@Service
public class TXlhtConfServiceImpl implements ITXlhtConfService
{
    @Autowired
    private TXlhtConfMapper tXlhtConfMapper;

    /**
     * 查询指标配置
     * 
     * @param id 指标配置主键
     * @return 指标配置
     */
    @Override
    public TXlhtConf selectTXlhtConfById(Long id)
    {
        return tXlhtConfMapper.selectTXlhtConfById(id);
    }

    /**
     * 查询指标配置列表
     * 
     * @param tXlhtConf 指标配置
     * @return 指标配置
     */
    @Override
    public List<TXlhtConf> selectTXlhtConfList(TXlhtConf tXlhtConf)
    {
        return tXlhtConfMapper.selectTXlhtConfList(tXlhtConf);
    }

    /**
     * 新增指标配置
     * 
     * @param tXlhtConf 指标配置
     * @return 结果
     */
    @Override
    public int insertTXlhtConf(TXlhtConf tXlhtConf)
    {
        tXlhtConf.setCreateTime(DateUtils.getNowDate());
        return tXlhtConfMapper.insertTXlhtConf(tXlhtConf);
    }

    /**
     * 修改指标配置
     * 
     * @param tXlhtConf 指标配置
     * @return 结果
     */
    @Override
    public int updateTXlhtConf(TXlhtConf tXlhtConf)
    {
        tXlhtConf.setUpdateTime(DateUtils.getNowDate());
        return tXlhtConfMapper.updateTXlhtConf(tXlhtConf);
    }

    /**
     * 批量删除指标配置
     * 
     * @param ids 需要删除的指标配置主键
     * @return 结果
     */
    @Override
    public int deleteTXlhtConfByIds(Long[] ids)
    {
        return tXlhtConfMapper.deleteTXlhtConfByIds(ids);
    }

    /**
     * 删除指标配置信息
     * 
     * @param id 指标配置主键
     * @return 结果
     */
    @Override
    public int deleteTXlhtConfById(Long id)
    {
        return tXlhtConfMapper.deleteTXlhtConfById(id);
    }
}
